[][src]Struct earl_lang_syntax::shared::ParsingError

pub struct ParsingError {
    pub error_code: ErrorCode,
    pub error_message: String,
}

Collection of error information returned to the user if there's a problem tokenizing or parsing the input.

NOTE: maybe find a better name? This is both for tokenizing and parsing.

Fields

error_code: ErrorCodeerror_message: String

Implementations

impl ParsingError[src]

pub fn new(
    code: &[u8],
    start_index: usize,
    end_index: usize,
    error_code: ErrorCode,
    error_message: &str
) -> ParsingError
[src]

This is for tokenization

TODO: maybe need differnt ones for parsing since we have access to different kind of information.

TODO: in future add hints or support for hints.