[−][src]Struct earl_lang_syntax::tokenizer::Token
A Token's id is its type, but I can't use type as the name of a field in
a struct.
A token keeps track of what kind of token it is, i.e. id, and at what byte it was found in
the input and how many bytes it spans.
- The field
idis what type of token this is. - The field
indexis the index of the byte where this token begins. - The field
lengthis how many bytes this token spans.
Fields
id: TokenIdasdfasdff
index: usizelength: usizeasdfasdff
lexeme: StringImplementations
impl Token[src]
pub fn new(id: TokenId, index: usize, length: usize) -> Token[src]
Creates a new token.
pub fn new_from_code(
id: TokenId,
index: usize,
length: usize,
code: &str
) -> Token[src]
id: TokenId,
index: usize,
length: usize,
code: &str
) -> Token
pub fn finalize(&mut self, code: &str)[src]
Convenience thing
pub fn get_lexeme<'a>(&self, code: &'a str) -> &'a str[src]